Package: qtlhot
Version: 1.2.10
Date: 2026-01-19
Authors@R: c(person(given = c("Elias", "Chaibub"),
                        family = "Neto",
                        role = "aut",
                        email = "echaibub@hotmail.com"),
                 person(given = c("Brian", "S"),
                        family = "Yandell",
                        role = "aut",
                        email = "brian.yandell@wisc.edu"),
                 person(given = c("Brian", "S."),
                        family = "Yandell",
                        role = "cre",
                        email = "brian.yandell@wisc.edu"))
Title: Inference for QTL Hotspots
Description: Functions to infer co-mapping trait hotspots and causal models.
  Chaibub Neto E, Keller MP, Broman AF, Attie AD, Jansen RC, Broman KW, Yandell BS (2012) 
  Quantile-based permutation thresholds for QTL hotspots. Genetics 191 : 1355-1365. 
  <doi:10.1534/genetics.112.139451>.
  Chaibub Neto E, Broman AT, Keller MP, Attie AD, Zhang B, Zhu J, Yandell BS (2013)
  Modeling causality for pairs of phenotypes in system genetics. Genetics 193 : 1003-1013.
  <doi:10.1534/genetics.112.147124>.
Maintainer: Brian S. Yandell <brian.yandell@wisc.edu>
Depends: stats,qtl,mnormt,utils,corpcor,broman, R (>= 3.5.0)
LazyLoad: true
LazyData: true
License: GPL (>= 2)
URL: https://github.com/byandell-sysgen/qtlhot
Encoding: UTF-8
RoxygenNote: 7.3.3
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-01-19 15:44:17 UTC; brianyandell
Author: Elias Chaibub Neto [aut],
  Brian S Yandell [aut],
  Brian S. Yandell [cre]
Repository: CRAN
Date/Publication: 2026-01-19 20:00:02 UTC
Built: R 4.6.0; ; 2026-04-28 09:12:18 UTC; unix
