# Generated by roxygen2: do not edit by hand

S3method(hotsize,highlod)
S3method(hotsize,scanone)
S3method(max,highlod)
S3method(max,hotsize)
S3method(plot,highlod)
S3method(plot,hotperm)
S3method(plot,hotsize)
S3method(print,highlod)
S3method(print,hotperm)
S3method(print,hotsize)
S3method(print,summary.hotperm)
S3method(print,ww.perm)
S3method(summary,highlod)
S3method(summary,hotperm)
S3method(summary,hotsize)
S3method(summary,ww.perm)
export(CMSTtests)
export(CMSTtestsList)
export(CitTests)
export(CombineTests)
export(FitAllTests)
export(GetCandReg)
export(GetCisCandReg)
export(GetCoMappingTraits)
export(GetCommonQtls)
export(JoinTestOutputs)
export(PrecTpFpMatrix)
export(SimCrossCausal)
export(highlod)
export(hotperm)
export(hotsize)
export(include.hotspots)
export(neqtl)
export(pull.highlod)
export(quantile_highlod)
export(quantile_hotperm)
export(sim.null.cross)
importFrom(broman,runningmean)
importFrom(corpcor,is.positive.definite)
importFrom(corpcor,make.positive.definite)
importFrom(mnormt,pmnorm)
importFrom(qtl,calc.genoprob)
importFrom(qtl,find.marker)
importFrom(qtl,find.pheno)
importFrom(qtl,find.pseudomarker)
importFrom(qtl,getsex)
importFrom(qtl,lodint)
importFrom(qtl,makeqtl)
importFrom(qtl,nchr)
importFrom(qtl,nind)
importFrom(qtl,nphe)
importFrom(qtl,pull.geno)
importFrom(qtl,pull.map)
importFrom(qtl,scanone)
importFrom(qtl,sim.cross)
importFrom(qtl,sim.map)
importFrom(stats,cor)
importFrom(stats,rnorm)
importFrom(stats,runif)
